  * {
    font-size: 1em;
  }
  .container {  
    display: grid;
    grid-template-columns: auto 1fr;
    grid-template-rows: min-content min-content min-content;
    gap: 0px 0px;
    grid-auto-flow: row;
    grid-template-areas:
      "info hostlist"
      "info chartlist"
      "info activities";
    padding: 0.3em;
    border: 1px solid #ccc;
    border-radius: 10px;
    margin-bottom: 5px;
  }
  
  .info {
    justify-self: center;
    align-self: center;
    grid-area: info;
    width: min-content;
    text-wrap: nowrap;
    padding: 0em 1em;
    }
  
  .hostlist { 
    justify-self: left;
    align-self: center;
    grid-area: hostlist; }
  
  .chartlist { 
    justify-self: left;
    align-self: center;
    grid-area: chartlist; }
  
  .activities { 
    justify-self: left;
    align-self: center;
    grid-area: activities; }
  
 
  div.activities ul, div.info ul, div.hostlist ul, div.chartlist ul  {
    padding: 0;
    margin: 0;
    list-style-type: none;
  }

  div.activities ul {
    display: flex;
    flex-wrap: wrap;
  }
  div.activities ul li {
    display: inline;
    padding: 0.3em;
    border: 1px solid #ccc;    
    border-radius: 5px;
    margin-bottom: 5px;
    margin-left: 0.2em;
  }
  #popup {
    display: none;
    position: absolute;
    min-width: 80%;
    max-width: 80%;
    margin: 0.7em;
    padding: 0.3em;
    background: #eee;
    border: solid 1px #000;
    border-radius: 5px;
    margin-bottom: 5px;
  }
  a:link, a:visited,  a:active {
    color: #5685bc;
    text-decoration: none;
  }
  a:hover {
    color:rgba(255, 0, 0, 0.650);
    text-decoration: none;
  }
  div.chart {
    height: 400px;
    padding: 5px;
    border: 1px solid #ccc;
    border-radius: 10px;
    margin-bottom: 5px;
  }
  li.active {
    background-color: #eee;
  }
  li.inactive {
    background-color: #fff;
  }  
  li.disabled {
    color: #ccc;
    background-color: #fff;
  }
  li.i_active {
    background-color: #eee;
  }
  li.i_inactive {
    background-color: #fff;
  }  
  li.i_disabled {
    color: #ccc;
    background-color: #fff;
  }
  .zg-ul-select:not(.active)::after {
    background-image: url('../img/chevron.svg');
  }
